{{
/**
 * Test program for rcsc generated spin files.
 *
 * Revision History:
 * December 28, 2007 v1.0: Initial release.
 * @author Peter Verkaik (verkaik6@zonnet.nl)
 */
}}


CON
  'clock settings for spin stamp
  _clkmode = xtal1+pll8x
  _xinfreq = 10_000_000
  
  debugPort = 2 '0=none, 1=propeller TX/RX, 2=spin stamp SOUT/SIN
  
  '//Spin stamp pin assignments
  stampSOUT = 16  'serial out (pin 1 of spin stamp)
  stampSIN  = 17  'serial in  (pin 2 of spin stamp)
  stampATN  = 18  'digital in (pin 3 of spin stamp, when activated, do reboot)

  '//Propeller system pin assignments
  propSCL = 28 'external eeprom SCL
  propSDA = 29 'external eeprom SDA
  propTX  = 30 'programming output
  propRX  = 31 'programming input

  'Datalogger SPI pins
  SPI_CLK   = 13                  ' Clock out       (connects to Vinculum SCLK pin)
  SPI_CS    = 11                  ' Chip Select out (connects to Vinculum CS pin)
  SPI_SDO   = 14                  ' Data out        (connects to Vinculum SDI pin) 
  SPI_SDI   = 10                  ' Data in         (connects to Vinculum SDO pin)

  CR = 13                         ' Carriage return


OBJ
  debug:   "MultiCogSerialDebug"    '//debug serial driver
  rcsc:    "rcsc"                   '//rcsc object
  proptst4: "proptst4"
  

CON
  rcsc_stacksize = 256
  
VAR
  byte debugSemID    'lock to be used by debug
  long atnStack[10]  'stack for monitoring ATN pin
  byte buffer[6]
  byte dirbuf[256]   'to hold directory command output
  word vmPR,vmSR,vmPC,vmSP
  word rcsc_main
  byte rcsc_stack[rcsc_stacksize]

PUB start | t, s
  'get lock for debug
  debugSemID := locknew
  'start debug
  case debugPort
    1: debug.start(propRX,propTX,0,9600,debugSemID)
    2: debug.start(stampSIN,stampSOUT,0,9600,debugSemID)
  waitcnt(clkfreq + cnt) 'wait 1 second
  'monitor ATN pin (optional)
'  if debugPort == 2
'    cognew(atnReset,@atnStack)

  'welcome message
  debug.cprintf(string("Test program for rcsc generated spin files\r"),0,false)

  'start rcsc interpreter
  rcsc_main := proptst4.getMain
  rcsc.reset(rcsc_main,@rcsc_stack,rcsc_stacksize)
  repeat
    rcsc.run(1)
  

PUB atnReset
  repeat  'loop endlessly
    if INA[stampATN] == 1
      reboot

      